@@ -2,7 +2,7 @@ from ._distribution import Distribution
 from ._beta import Beta
 from ._cauchy_diff import Cauchy_diff
 from ._gamma import Gamma
-from ._gaussian import Gaussian, GaussianCov, GaussianPrec, GaussianSqrtPrec, JointGaussianSqrtPrec
+from ._gaussian import Gaussian, JointGaussianSqrtPrec
 from ._gmrf import GMRF
 from ._inverse_gamma import InverseGamma
 from ._laplace_diff import Laplace_diff
