@@ -91,10 +91,10 @@ class Deblur(BayesianProblem):
         
         # Prior
         if prior is None:
-            prior = Gaussian(np.zeros(dim), 1, np.eye(dim), name="x")
+            prior = Gaussian(np.zeros(dim), 1, name="x")
 
         # Store data distribution
-        data_dist = Gaussian(model(prior), noise_std, np.eye(dim), name="y")
+        data_dist = Gaussian(model(prior), noise_std**2, name="y")
         
         # Generate inverse-crime free data (still same blur size)
         data, f_true, g_true = self._generateData(mesh, kernel, blur_size, data_dist)
@@ -233,9 +233,9 @@ class Deconvolution1D(BayesianProblem):
 
         # Define and add noise #TODO: Add Poisson and logpoisson
         if noise_type.lower() == "gaussian":
-            data_dist = cuqi.distribution.Gaussian(model(prior), noise_std, np.eye(dim), name="y")
+            data_dist = cuqi.distribution.Gaussian(model(prior), noise_std**2, name="y")
         elif noise_type.lower() == "scaledgaussian":
-            data_dist = cuqi.distribution.Gaussian(model(prior), y_exact*noise_std, np.eye(dim), name="y")
+            data_dist = cuqi.distribution.Gaussian(model(prior), (y_exact*noise_std)**2, name="y")
         else:
             raise NotImplementedError("This noise type is not implemented")
         
@@ -467,7 +467,7 @@ class Poisson_1D(BayesianProblem):
         NB: Requires prior to be defined.
 
     """
-    def __init__(self, dim=128, endpoint=1, source=lambda xs: 10*np.exp( -( (xs - 0.5)**2 ) / 0.02), field_type=None, field_params=None, map=None, imap=None, SNR=200, observation_grid_map=None):
+    def __init__(self, dim=128, endpoint=1, source=lambda xs: 10*np.exp( -( (xs - 0.5)**2 ) / 0.02), field_type=None, field_params=None, map=None, imap=None, SNR=200, observation_grid_map=None, exactSolution=None):
 
         # Prepare PDE form
         N = dim-1   # Number of solution nodes
@@ -510,13 +510,16 @@ class Poisson_1D(BayesianProblem):
         if map is not None:
             domain_geometry = MappedGeometry(domain_geometry, map, imap)
 
-        range_geometry = Continuous1D(grid_range)
+        range_geometry = Continuous1D(grid_obs)
 
         # Prepare model
         model = cuqi.model.PDEModel(PDE,range_geometry,domain_geometry)
 
         # Set up exact solution
-        x_exact = np.exp( 5*grid_domain*np.exp(-2*grid_domain)*np.sin(endpoint-grid_domain) )   
+        if exactSolution is None:
+            x_exact = np.exp( 5*grid_domain*np.exp(-2*grid_domain)*np.sin(endpoint-grid_domain) ) 
+        else: 
+            x_exact = exactSolution 
         x_exact = CUQIarray(x_exact, is_par=False, geometry=domain_geometry)
 
         # Generate exact data
@@ -528,8 +531,8 @@ class Poisson_1D(BayesianProblem):
         data = y_exact + np.random.normal(0, sigma, y_exact.shape)
 
         # Bayesian model
-        x = cuqi.distribution.GaussianCov(np.zeros(model.domain_dim), 1)
-        y = cuqi.distribution.GaussianCov(model, sigma2*np.eye(model.range_dim))
+        x = cuqi.distribution.Gaussian(np.zeros(model.domain_dim), 1)
+        y = cuqi.distribution.Gaussian(model, sigma2)
 
         # Initialize Deconvolution as BayesianProblem problem
         super().__init__(y, x, y=data)
@@ -679,8 +682,8 @@ class Heat_1D(BayesianProblem):
         data = y_exact + np.random.normal(0, sigma, y_exact.shape)
 
         # Bayesian model
-        x = cuqi.distribution.GaussianCov(np.zeros(model.domain_dim), 1)
-        y = cuqi.distribution.GaussianCov(model(x), sigma2*np.eye(model.range_dim))
+        x = cuqi.distribution.Gaussian(np.zeros(model.domain_dim), 1)
+        y = cuqi.distribution.Gaussian(model(x), sigma2)
         
         # Initialize Deconvolution as BayesianProblem problem
         super().__init__(y, x, y=data)
@@ -798,8 +801,8 @@ class Abel_1D(BayesianProblem):
         data = y_exact + np.random.normal(0, sigma, y_exact.shape )
 
         # Bayesian model
-        x = cuqi.distribution.GaussianCov(np.zeros(model.domain_dim), 1)
-        y = cuqi.distribution.GaussianCov(model(x), sigma2*np.eye(model.range_dim))
+        x = cuqi.distribution.Gaussian(np.zeros(model.domain_dim), 1)
+        y = cuqi.distribution.Gaussian(model(x), sigma2)
         
         # Initialize Deconvolution as BayesianProblem problem
         super().__init__(y, x, y=data)
@@ -900,7 +903,7 @@ class Deconv_1D(BayesianProblem):
         model = LinearModel(A,range_geometry=range_geometry, domain_geometry=domain_geometry)
     
         # Prior
-        prior = cuqi.distribution.GaussianCov(np.zeros(model.domain_dim), 1, geometry=model.domain_geometry, name="x")
+        prior = cuqi.distribution.Gaussian(np.zeros(model.domain_dim), 1, geometry=model.domain_geometry, name="x")
 
         # Set up exact solution
         x_exact = prior.sample()
@@ -913,7 +916,7 @@ class Deconv_1D(BayesianProblem):
         sigma2 = sigma*sigma # variance of the observation Gaussian noise
         data = y_exact + np.random.normal(0, sigma, y_exact.shape)
 
-        likelihood = cuqi.distribution.GaussianCov(model(prior), sigma2*np.eye(model.range_dim), name="y").to_likelihood(data)
+        likelihood = cuqi.distribution.Gaussian(model(prior), sigma2, name="y").to_likelihood(data)
         
         # Initialize Deconvolution as BayesianProblem problem
         super().__init__(likelihood, prior)
@@ -1102,13 +1105,13 @@ class Deconvolution2D(BayesianProblem):
 
         # Create prior
         if prior is None:
-            prior = cuqi.distribution.GaussianCov(np.zeros(model.domain_dim), 1, geometry=domain_geometry, name="x")
+            prior = cuqi.distribution.Gaussian(np.zeros(model.domain_dim), 1, geometry=domain_geometry, name="x")
 
         # Data distribution
         if noise_type.lower() == "gaussian":
-            data_dist = cuqi.distribution.GaussianCov(model(prior), noise_std**2, geometry=range_geometry, name="y")
+            data_dist = cuqi.distribution.Gaussian(model(prior), noise_std**2, geometry=range_geometry, name="y")
         elif noise_type.lower() == "scaledgaussian":
-            data_dist = cuqi.distribution.GaussianCov(model(prior), (y_exact*noise_std)**2, geometry=range_geometry, name="y")
+            data_dist = cuqi.distribution.Gaussian(model(prior), (y_exact*noise_std)**2, geometry=range_geometry, name="y")
         else:
             raise NotImplementedError("This noise type is not implemented")
         
@@ -1254,7 +1257,7 @@ class WangCubic(BayesianProblem):
             data = 1
 
         # data distribution is Gaussian
-        data_dist = cuqi.distribution.Gaussian(model(prior), noise_std, name="y")
+        data_dist = cuqi.distribution.Gaussian(model(prior), noise_std**2, name="y")
 
         # Define Gaussian likelihood
         likelihood = data_dist.to_likelihood(data)
